'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function noop() {}

function assign(target) {
	var k,
		source,
		i = 1,
		len = arguments.length;
	for (; i < len; i++) {
		source = arguments[i];
		for (k in source) target[k] = source[k];
	}

	return target;
}

function appendNode(node, target) {
	target.appendChild(node);
}

function insertNode(node, target, anchor) {
	target.insertBefore(node, anchor);
}

function detachNode(node) {
	node.parentNode.removeChild(node);
}

function createElement(name) {
	return document.createElement(name);
}

function createText(data) {
	return document.createTextNode(data);
}

function createComment() {
	return document.createComment('');
}

function addListener(node, event, handler) {
	node.addEventListener(event, handler, false);
}

function removeListener(node, event, handler) {
	node.removeEventListener(event, handler, false);
}

function setAttribute(node, attribute, value) {
	node.setAttribute(attribute, value);
}

function differs(a, b) {
	return a !== b || ((a && typeof a === 'object') || typeof a === 'function');
}

function dispatchObservers(component, group, newState, oldState) {
	for (var key in group) {
		if (!(key in newState)) continue;

		var newValue = newState[key];
		var oldValue = oldState[key];

		if (differs(newValue, oldValue)) {
			var callbacks = group[key];
			if (!callbacks) continue;

			for (var i = 0; i < callbacks.length; i += 1) {
				var callback = callbacks[i];
				if (callback.__calling) continue;

				callback.__calling = true;
				callback.call(component, newValue, oldValue);
				callback.__calling = false;
			}
		}
	}
}

function get(key) {
	return key ? this._state[key] : this._state;
}

function fire(eventName, data) {
	var handlers =
		eventName in this._handlers && this._handlers[eventName].slice();
	if (!handlers) return;

	for (var i = 0; i < handlers.length; i += 1) {
		handlers[i].call(this, data);
	}
}

function observe(key, callback, options) {
	var group = options && options.defer
		? this._observers.post
		: this._observers.pre;

	(group[key] || (group[key] = [])).push(callback);

	if (!options || options.init !== false) {
		callback.__calling = true;
		callback.call(this, this._state[key]);
		callback.__calling = false;
	}

	return {
		cancel: function() {
			var index = group[key].indexOf(callback);
			if (~index) group[key].splice(index, 1);
		}
	};
}

function on(eventName, handler) {
	if (eventName === 'teardown') return this.on('destroy', handler);

	var handlers = this._handlers[eventName] || (this._handlers[eventName] = []);
	handlers.push(handler);

	return {
		cancel: function() {
			var index = handlers.indexOf(handler);
			if (~index) handlers.splice(index, 1);
		}
	};
}

function set(newState) {
	this._set(assign({}, newState));
	callAll(this._root._oncreate);
}

function callAll(fns) {
	while (fns && fns.length) fns.pop()();
}

var proto = {
	get: get,
	fire: fire,
	observe: observe,
	on: on,
	set: set
};

function create_main_fragment$1 ( state, component ) {
	var button, span, text;

	function click_handler ( event ) {
		component.fire('click');
	}

	return {
		create: function () {
			button = createElement( 'button' );
			span = createElement( 'span' );
			text = createText( "×" );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			button.type = "button";
			button.className = "close";
			setAttribute( button, 'aria-label', "Close" );
			addListener( button, 'click', click_handler );
			setAttribute( span, 'aria-hidden', "true" );
		},

		mount: function ( target, anchor ) {
			insertNode( button, target, anchor );
			appendNode( span, button );
			appendNode( text, span );
		},

		unmount: function () {
			detachNode( button );
		},

		destroy: function () {
			removeListener( button, 'click', click_handler );
		}
	};
}

function Close ( options ) {
	options = options || {};
	this._state = options.data || {};

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$1( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( Close.prototype, proto );

Close.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

Close.prototype.teardown = Close.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template = (function () {
  // TODO handle fade transition when dismissing

  return {
    data() {
      return {
        class: '',
        color: 'success',
        isOpen: true,
        dismissible: false
      };
    }
  }
}());

function create_main_fragment ( state, component ) {
	var if_block_anchor;

	var if_block = (state.isOpen) && create_if_block( state, component );

	return {
		create: function () {
			if ( if_block ) if_block.create();
			if_block_anchor = createComment();
		},

		mount: function ( target, anchor ) {
			if ( if_block ) if_block.mount( target, anchor );
			insertNode( if_block_anchor, target, anchor );
		},

		update: function ( changed, state ) {
			if ( state.isOpen ) {
				if ( if_block ) {
					if_block.update( changed, state );
				} else {
					if_block = create_if_block( state, component );
					if_block.create();
					if_block.mount( if_block_anchor.parentNode, if_block_anchor );
				}
			} else if ( if_block ) {
				if_block.unmount();
				if_block.destroy();
				if_block = null;
			}
		},

		unmount: function () {
			if ( if_block ) if_block.unmount();
			detachNode( if_block_anchor );
		},

		destroy: function () {
			if ( if_block ) if_block.destroy();
		}
	};
}

function create_if_block_1 ( state, component ) {

	var close = new Close({
		_root: component._root
	});

	close.on( 'click', function ( event ) {
		component.set({ isOpen: false });
	});

	return {
		create: function () {
			close._fragment.create();
		},

		mount: function ( target, anchor ) {
			close._fragment.mount( target, anchor );
		},

		unmount: function () {
			close._fragment.unmount();
		},

		destroy: function () {
			close.destroy( false );
		}
	};
}

function create_if_block ( state, component ) {
	var div, div_class_value, text;

	var if_block_1 = (state.dismissible) && create_if_block_1( state, component );

	return {
		create: function () {
			div = createElement( 'div' );
			if ( if_block_1 ) if_block_1.create();
			text = createText( "\n    " );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			div.className = div_class_value = "alert alert-" + ( state.color ) + ( state.dismissible ? ' alert-dismissible' : '' ) + " " + ( state.class );
			setAttribute( div, 'role', "alert" );
		},

		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			if ( if_block_1 ) if_block_1.mount( div, null );
			appendNode( text, div );
			if ( component._yield ) component._yield.mount( div, null );
		},

		update: function ( changed, state ) {
			if ( div_class_value !== ( div_class_value = "alert alert-" + ( state.color ) + ( state.dismissible ? ' alert-dismissible' : '' ) + " " + ( state.class ) ) ) {
				div.className = div_class_value;
			}

			if ( state.dismissible ) {
				if ( !if_block_1 ) {
					if_block_1 = create_if_block_1( state, component );
					if_block_1.create();
					if_block_1.mount( div, text );
				}
			} else if ( if_block_1 ) {
				if_block_1.unmount();
				if_block_1.destroy();
				if_block_1 = null;
			}
		},

		unmount: function () {
			detachNode( div );
			if ( if_block_1 ) if_block_1.unmount();
			if ( component._yield ) component._yield.unmount();
		},

		destroy: function () {
			if ( if_block_1 ) if_block_1.destroy();
		}
	};
}

function Alert ( options ) {
	options = options || {};
	this._state = assign( template.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;
	this._oncreate = [];

	this._fragment = create_main_fragment( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}

	callAll(this._oncreate);
}

assign( Alert.prototype, proto );

Alert.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
	callAll(this._oncreate);
};

Alert.prototype.teardown = Alert.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$1 = (function () {
  return {
    data() {
      return {
        class: '',
        color: 'default',
        pill: false
      };
    }
  };
}());

function create_main_fragment$2 ( state, component ) {
	var span, span_class_value;

	return {
		create: function () {
			span = createElement( 'span' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			span.className = span_class_value = "badge badge-" + ( state.color ) + ( state.pill ? ' badge-pill' : '' ) + " " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( span, target, anchor );
			if ( component._yield ) component._yield.mount( span, null );
		},

		update: function ( changed, state ) {
			if ( span_class_value !== ( span_class_value = "badge badge-" + ( state.color ) + ( state.pill ? ' badge-pill' : '' ) + " " + ( state.class ) ) ) {
				span.className = span_class_value;
			}
		},

		unmount: function () {
			detachNode( span );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function Badge ( options ) {
	options = options || {};
	this._state = assign( template$1.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$2( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( Badge.prototype, proto );

Badge.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

Badge.prototype.teardown = Badge.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$2 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function create_main_fragment$3 ( state, component ) {
	var ol, ol_class_value;

	return {
		create: function () {
			ol = createElement( 'ol' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			ol.className = ol_class_value = "breadcrumb " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( ol, target, anchor );
			if ( component._yield ) component._yield.mount( ol, null );
		},

		update: function ( changed, state ) {
			if ( ol_class_value !== ( ol_class_value = "breadcrumb " + ( state.class ) ) ) {
				ol.className = ol_class_value;
			}
		},

		unmount: function () {
			detachNode( ol );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function Breadcrumb ( options ) {
	options = options || {};
	this._state = assign( template$2.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$3( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( Breadcrumb.prototype, proto );

Breadcrumb.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

Breadcrumb.prototype.teardown = Breadcrumb.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$3 = (function () {
  return {
    data() {
      return {
        active: false,
        class: ''
      }
    }
  }
}());

function create_main_fragment$4 ( state, component ) {
	var li, li_class_value;

	return {
		create: function () {
			li = createElement( 'li' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			li.className = li_class_value = "breadcrumb-item" + ( state.active ? ' active' : '' ) + " " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( li, target, anchor );
			if ( component._yield ) component._yield.mount( li, null );
		},

		update: function ( changed, state ) {
			if ( li_class_value !== ( li_class_value = "breadcrumb-item" + ( state.active ? ' active' : '' ) + " " + ( state.class ) ) ) {
				li.className = li_class_value;
			}
		},

		unmount: function () {
			detachNode( li );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function BreadcrumbItem ( options ) {
	options = options || {};
	this._state = assign( template$3.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$4( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( BreadcrumbItem.prototype, proto );

BreadcrumbItem.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

BreadcrumbItem.prototype.teardown = BreadcrumbItem.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$4 = (function () {
  return {
    methods: {
      onClick(e) {
        const { disabled } = this.get();
        if (disabled) {
          e.preventDefault();
          return;
        } else {
          this.fire('click', e);
        }
      }
    },
    data() {
      return {
        active: false,
        block: false,
        class: '',
        color: 'secondary',
        outline: false,
        size: null
      }
    }
  }
}());

function create_main_fragment$5 ( state, component ) {
	var Button_1, Button_1_class_value;

	function click_handler ( event ) {
		component.onClick(event);
	}

	return {
		create: function () {
			Button_1 = createElement( 'Button' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			Button_1.className = Button_1_class_value = "btn btn" + ( state.outline ? '-outline' : '' ) + "-" + ( state.color ) + ( state.size ? ` btn-${state.size}` : '' ) + ( state.block ? ' btn-block' : '' ) + ( state.active ? ' active' : '' ) + ( state.disabled ? ' disabled' : '' ) + " " + ( state.class );
			addListener( Button_1, 'click', click_handler );
		},

		mount: function ( target, anchor ) {
			insertNode( Button_1, target, anchor );
			if ( component._yield ) component._yield.mount( Button_1, null );
		},

		update: function ( changed, state ) {
			if ( Button_1_class_value !== ( Button_1_class_value = "btn btn" + ( state.outline ? '-outline' : '' ) + "-" + ( state.color ) + ( state.size ? ` btn-${state.size}` : '' ) + ( state.block ? ' btn-block' : '' ) + ( state.active ? ' active' : '' ) + ( state.disabled ? ' disabled' : '' ) + " " + ( state.class ) ) ) {
				Button_1.className = Button_1_class_value;
			}
		},

		unmount: function () {
			detachNode( Button_1 );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: function () {
			removeListener( Button_1, 'click', click_handler );
		}
	};
}

function Button ( options ) {
	options = options || {};
	this._state = assign( template$4.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$5( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( Button.prototype, template$4.methods, proto );

Button.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

Button.prototype.teardown = Button.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$5 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function create_main_fragment$6 ( state, component ) {
	var div, div_class_value;

	return {
		create: function () {
			div = createElement( 'div' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			div.className = div_class_value = "" + ( state.size ? `btn-group-${state.size} ` : '' ) + ( state.vertical ? 'btn-group-vertical' : 'btn-group' ) + " " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			if ( component._yield ) component._yield.mount( div, null );
		},

		update: function ( changed, state ) {
			if ( div_class_value !== ( div_class_value = "" + ( state.size ? `btn-group-${state.size} ` : '' ) + ( state.vertical ? 'btn-group-vertical' : 'btn-group' ) + " " + ( state.class ) ) ) {
				div.className = div_class_value;
			}
		},

		unmount: function () {
			detachNode( div );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function ButtonGroup ( options ) {
	options = options || {};
	this._state = assign( template$5.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$6( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( ButtonGroup.prototype, proto );

ButtonGroup.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

ButtonGroup.prototype.teardown = ButtonGroup.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$6 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function create_main_fragment$7 ( state, component ) {
	var div, div_class_value;

	return {
		create: function () {
			div = createElement( 'div' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			div.className = div_class_value = "btn-toolbar " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			if ( component._yield ) component._yield.mount( div, null );
		},

		update: function ( changed, state ) {
			if ( div_class_value !== ( div_class_value = "btn-toolbar " + ( state.class ) ) ) {
				div.className = div_class_value;
			}
		},

		unmount: function () {
			detachNode( div );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function ButtonToolbar ( options ) {
	options = options || {};
	this._state = assign( template$6.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$7( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( ButtonToolbar.prototype, proto );

ButtonToolbar.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

ButtonToolbar.prototype.teardown = ButtonToolbar.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$7 = (function () {
  return {
    data() {
      return {
        block: false,
        class: '',
        inverse: false,
        outline: false
      }
    }
  }
}());

function create_main_fragment$8 ( state, component ) {
	var div, div_class_value;

	return {
		create: function () {
			div = createElement( 'div' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			div.className = div_class_value = "card" + ( state.inverse ? ' card-inverse' : '' ) + ( state.block ? ' card-block' : '' ) + ( state.color ? ` card${state.outline ? '-outline' : ''}-${state.color}` : '' ) + " " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			if ( component._yield ) component._yield.mount( div, null );
		},

		update: function ( changed, state ) {
			if ( div_class_value !== ( div_class_value = "card" + ( state.inverse ? ' card-inverse' : '' ) + ( state.block ? ' card-block' : '' ) + ( state.color ? ` card${state.outline ? '-outline' : ''}-${state.color}` : '' ) + " " + ( state.class ) ) ) {
				div.className = div_class_value;
			}
		},

		unmount: function () {
			detachNode( div );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function Card ( options ) {
	options = options || {};
	this._state = assign( template$7.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$8( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( Card.prototype, proto );

Card.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

Card.prototype.teardown = Card.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$8 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function create_main_fragment$9 ( state, component ) {
	var div, div_class_value;

	return {
		create: function () {
			div = createElement( 'div' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			div.className = div_class_value = "card-block " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			if ( component._yield ) component._yield.mount( div, null );
		},

		update: function ( changed, state ) {
			if ( div_class_value !== ( div_class_value = "card-block " + ( state.class ) ) ) {
				div.className = div_class_value;
			}
		},

		unmount: function () {
			detachNode( div );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function CardBlock ( options ) {
	options = options || {};
	this._state = assign( template$8.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$9( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( CardBlock.prototype, proto );

CardBlock.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

CardBlock.prototype.teardown = CardBlock.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$9 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function create_main_fragment$10 ( state, component ) {
	var div, div_class_value;

	return {
		create: function () {
			div = createElement( 'div' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			div.className = div_class_value = "card-columns " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			if ( component._yield ) component._yield.mount( div, null );
		},

		update: function ( changed, state ) {
			if ( div_class_value !== ( div_class_value = "card-columns " + ( state.class ) ) ) {
				div.className = div_class_value;
			}
		},

		unmount: function () {
			detachNode( div );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function CardColumns ( options ) {
	options = options || {};
	this._state = assign( template$9.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$10( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( CardColumns.prototype, proto );

CardColumns.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

CardColumns.prototype.teardown = CardColumns.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$10 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function create_main_fragment$11 ( state, component ) {
	var div, div_class_value;

	return {
		create: function () {
			div = createElement( 'div' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			div.className = div_class_value = "card-deck " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			if ( component._yield ) component._yield.mount( div, null );
		},

		update: function ( changed, state ) {
			if ( div_class_value !== ( div_class_value = "card-deck " + ( state.class ) ) ) {
				div.className = div_class_value;
			}
		},

		unmount: function () {
			detachNode( div );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function CardDeck ( options ) {
	options = options || {};
	this._state = assign( template$10.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$11( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( CardDeck.prototype, proto );

CardDeck.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

CardDeck.prototype.teardown = CardDeck.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$11 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function create_main_fragment$12 ( state, component ) {
	var div, div_class_value;

	return {
		create: function () {
			div = createElement( 'div' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			div.className = div_class_value = "card-footer " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			if ( component._yield ) component._yield.mount( div, null );
		},

		update: function ( changed, state ) {
			if ( div_class_value !== ( div_class_value = "card-footer " + ( state.class ) ) ) {
				div.className = div_class_value;
			}
		},

		unmount: function () {
			detachNode( div );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function CardFooter ( options ) {
	options = options || {};
	this._state = assign( template$11.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$12( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( CardFooter.prototype, proto );

CardFooter.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

CardFooter.prototype.teardown = CardFooter.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$12 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function create_main_fragment$13 ( state, component ) {
	var div, div_class_value;

	return {
		create: function () {
			div = createElement( 'div' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			div.className = div_class_value = "card-group " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			if ( component._yield ) component._yield.mount( div, null );
		},

		update: function ( changed, state ) {
			if ( div_class_value !== ( div_class_value = "card-group " + ( state.class ) ) ) {
				div.className = div_class_value;
			}
		},

		unmount: function () {
			detachNode( div );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function CardGroup ( options ) {
	options = options || {};
	this._state = assign( template$12.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$13( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( CardGroup.prototype, proto );

CardGroup.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

CardGroup.prototype.teardown = CardGroup.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$13 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function create_main_fragment$14 ( state, component ) {
	var div, div_class_value;

	return {
		create: function () {
			div = createElement( 'div' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			div.className = div_class_value = "card-header " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			if ( component._yield ) component._yield.mount( div, null );
		},

		update: function ( changed, state ) {
			if ( div_class_value !== ( div_class_value = "card-header " + ( state.class ) ) ) {
				div.className = div_class_value;
			}
		},

		unmount: function () {
			detachNode( div );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function CardHeader ( options ) {
	options = options || {};
	this._state = assign( template$13.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$14( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( CardHeader.prototype, proto );

CardHeader.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

CardHeader.prototype.teardown = CardHeader.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$14 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function create_main_fragment$15 ( state, component ) {
	var div, div_class_value;

	return {
		create: function () {
			div = createElement( 'div' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			div.className = div_class_value = "card-img-overlay " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			if ( component._yield ) component._yield.mount( div, null );
		},

		update: function ( changed, state ) {
			if ( div_class_value !== ( div_class_value = "card-img-overlay " + ( state.class ) ) ) {
				div.className = div_class_value;
			}
		},

		unmount: function () {
			detachNode( div );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function CardImgOverlay ( options ) {
	options = options || {};
	this._state = assign( template$14.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$15( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( CardImgOverlay.prototype, proto );

CardImgOverlay.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

CardImgOverlay.prototype.teardown = CardImgOverlay.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$15 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function create_main_fragment$16 ( state, component ) {
	var h6, h6_class_value;

	return {
		create: function () {
			h6 = createElement( 'h6' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			h6.className = h6_class_value = "card-subtitle " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( h6, target, anchor );
			if ( component._yield ) component._yield.mount( h6, null );
		},

		update: function ( changed, state ) {
			if ( h6_class_value !== ( h6_class_value = "card-subtitle " + ( state.class ) ) ) {
				h6.className = h6_class_value;
			}
		},

		unmount: function () {
			detachNode( h6 );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function CardSubtitle ( options ) {
	options = options || {};
	this._state = assign( template$15.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$16( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( CardSubtitle.prototype, proto );

CardSubtitle.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

CardSubtitle.prototype.teardown = CardSubtitle.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$16 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function create_main_fragment$17 ( state, component ) {
	var p, p_class_value;

	return {
		create: function () {
			p = createElement( 'p' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			p.className = p_class_value = "card-text " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( p, target, anchor );
			if ( component._yield ) component._yield.mount( p, null );
		},

		update: function ( changed, state ) {
			if ( p_class_value !== ( p_class_value = "card-text " + ( state.class ) ) ) {
				p.className = p_class_value;
			}
		},

		unmount: function () {
			detachNode( p );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function CardText ( options ) {
	options = options || {};
	this._state = assign( template$16.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$17( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( CardText.prototype, proto );

CardText.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

CardText.prototype.teardown = CardText.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$17 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function create_main_fragment$18 ( state, component ) {
	var h4, h4_class_value;

	return {
		create: function () {
			h4 = createElement( 'h4' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			h4.className = h4_class_value = "card-title " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( h4, target, anchor );
			if ( component._yield ) component._yield.mount( h4, null );
		},

		update: function ( changed, state ) {
			if ( h4_class_value !== ( h4_class_value = "card-title " + ( state.class ) ) ) {
				h4.className = h4_class_value;
			}
		},

		unmount: function () {
			detachNode( h4 );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function CardTitle ( options ) {
	options = options || {};
	this._state = assign( template$17.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$18( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( CardTitle.prototype, proto );

CardTitle.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

CardTitle.prototype.teardown = CardTitle.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

function recompute ( state, newState, oldState, isInitial ) {
	if ( isInitial || ( 'widths' in newState && differs( state.widths, oldState.widths ) ) || ( 'xs' in newState && differs( state.xs, oldState.xs ) ) || ( 'sm' in newState && differs( state.sm, oldState.sm ) ) || ( 'md' in newState && differs( state.md, oldState.md ) ) || ( 'lg' in newState && differs( state.lg, oldState.lg ) ) || ( 'xl' in newState && differs( state.xl, oldState.xl ) ) ) {
		state.classes = newState.classes = template$18.computed.classes( state.widths, state.xs, state.sm, state.md, state.lg, state.xl );
	}
}

var template$18 = (function () {
  const widths = ['xs', 'sm', 'md', 'lg', 'xl'];

  function isObject(value) {
    const type = typeof value;
    return value != null && (type == 'object' || type == 'function');
  }

  const getColumnSizeClass = (isXs, colWidth, colSize) => {
    if (colSize === true || colSize === '') {
      return isXs ? 'col' : `col-${colWidth}`;
    } else if (colSize === 'auto') {
      return isXs ? 'col-auto' : `col-${colWidth}-auto`;
    }

    return isXs ? `col-${colSize}` : `col-${colWidth}-${colSize}`;
  };

  return {
    data() {
      return {
        class: '',
        widths
      }
    },
    computed: {
      classes(widths, xs, sm, md, lg, xl) {
        const colClasses = [];
        const props = {
          xs,
          sm,
          md,
          lg,
          xl
        };

        widths.forEach((colWidth, i) => {
          let columnProp = props[colWidth];

          if (!i && columnProp === undefined) {
            columnProp = true;
          }

          if (!columnProp) {
            return;
          }

          const isXs = !i;
          let colClass;

          if (isObject(columnProp)) {
            const colSizeInterfix = isXs ? '-' : `-${colWidth}-`;
            colClass = getColumnSizeClass(isXs, colWidth, columnProp.size);

            if (columnProp.size || columnProp.size === '') colClasses.push(colClass);
            if (columnProp.push) colClasses.push(`push${colSizeInterfix}${columnProp.push}`);
            if (columnProp.pull) colClasses.push(`pull${colSizeInterfix}${columnProp.pull}`);
            if (columnProp.offset) colClasses.push(`offset${colSizeInterfix}${columnProp.offset}`);
          } else {
            colClass = getColumnSizeClass(isXs, colWidth, columnProp);
            colClasses.push(colClass);
          }
        });
        
        return colClasses.join(' ');
      }
    }
  }
}());

function create_main_fragment$19 ( state, component ) {
	var div, div_class_value;

	return {
		create: function () {
			div = createElement( 'div' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			div.className = div_class_value = "" + ( state.classes ) + " " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			if ( component._yield ) component._yield.mount( div, null );
		},

		update: function ( changed, state ) {
			if ( div_class_value !== ( div_class_value = "" + ( state.classes ) + " " + ( state.class ) ) ) {
				div.className = div_class_value;
			}
		},

		unmount: function () {
			detachNode( div );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function Col ( options ) {
	options = options || {};
	this._state = assign( template$18.data(), options.data );
	recompute( this._state, this._state, {}, true );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$19( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( Col.prototype, proto );

Col.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	recompute( this._state, newState, oldState, false );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

Col.prototype.teardown = Col.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$19 = (function () {
  return {
    data() {
      return {
        class: '',
        fluid: false
      }
    }
  };
}());

function create_main_fragment$20 ( state, component ) {
	var div, div_class_value;

	return {
		create: function () {
			div = createElement( 'div' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			div.className = div_class_value = "container" + ( state.fluid ? '-fluid' : '' ) + " " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			if ( component._yield ) component._yield.mount( div, null );
		},

		update: function ( changed, state ) {
			if ( div_class_value !== ( div_class_value = "container" + ( state.fluid ? '-fluid' : '' ) + " " + ( state.class ) ) ) {
				div.className = div_class_value;
			}
		},

		unmount: function () {
			detachNode( div );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function Container ( options ) {
	options = options || {};
	this._state = assign( template$19.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$20( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( Container.prototype, proto );

Container.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

Container.prototype.teardown = Container.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$20 = (function () {
  // TODO manage open logic internally to this component, if possible
  // TODO support closing from click outside
  return {
    data() {
      return {
        class: '',
        dropup: false,
        open: false
      }
    }
  }
}());

function create_main_fragment$21 ( state, component ) {
	var div, div_class_value;

	return {
		create: function () {
			div = createElement( 'div' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			div.className = div_class_value = "dropdown" + ( state.dropup ? ' dropup' : '' ) + ( state.open ? ' show' : '' ) + " " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			if ( component._yield ) component._yield.mount( div, null );
		},

		update: function ( changed, state ) {
			if ( div_class_value !== ( div_class_value = "dropdown" + ( state.dropup ? ' dropup' : '' ) + ( state.open ? ' show' : '' ) + " " + ( state.class ) ) ) {
				div.className = div_class_value;
			}
		},

		unmount: function () {
			detachNode( div );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function Dropdown ( options ) {
	options = options || {};
	this._state = assign( template$20.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$21( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( Dropdown.prototype, proto );

Dropdown.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

Dropdown.prototype.teardown = Dropdown.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$21 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }

}());

function create_main_fragment$22 ( state, component ) {
	var div, div_class_value;

	return {
		create: function () {
			div = createElement( 'div' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			div.className = div_class_value = "dropdown-divider " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
		},

		update: function ( changed, state ) {
			if ( div_class_value !== ( div_class_value = "dropdown-divider " + ( state.class ) ) ) {
				div.className = div_class_value;
			}
		},

		unmount: function () {
			detachNode( div );
		},

		destroy: noop
	};
}

function DropdownDivider ( options ) {
	options = options || {};
	this._state = assign( template$21.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$22( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( DropdownDivider.prototype, proto );

DropdownDivider.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

DropdownDivider.prototype.teardown = DropdownDivider.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$22 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }

}());

function create_main_fragment$23 ( state, component ) {
	var h6, h6_class_value;

	return {
		create: function () {
			h6 = createElement( 'h6' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			h6.className = h6_class_value = "dropdown-header " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( h6, target, anchor );
			if ( component._yield ) component._yield.mount( h6, null );
		},

		update: function ( changed, state ) {
			if ( h6_class_value !== ( h6_class_value = "dropdown-header " + ( state.class ) ) ) {
				h6.className = h6_class_value;
			}
		},

		unmount: function () {
			detachNode( h6 );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function DropdownHeader ( options ) {
	options = options || {};
	this._state = assign( template$22.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$23( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( DropdownHeader.prototype, proto );

DropdownHeader.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

DropdownHeader.prototype.teardown = DropdownHeader.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$23 = (function () {
  return {
    data() {
      return {
        class: '',
        disabled: false
      }
    }
  }

}());

function create_main_fragment$24 ( state, component ) {
	var button, button_class_value;

	return {
		create: function () {
			button = createElement( 'button' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			button.className = button_class_value = "dropdown-item" + ( state.disabled ? ' disabled' : '' ) + " " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( button, target, anchor );
			if ( component._yield ) component._yield.mount( button, null );
		},

		update: function ( changed, state ) {
			if ( button_class_value !== ( button_class_value = "dropdown-item" + ( state.disabled ? ' disabled' : '' ) + " " + ( state.class ) ) ) {
				button.className = button_class_value;
			}
		},

		unmount: function () {
			detachNode( button );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function DropdownItem ( options ) {
	options = options || {};
	this._state = assign( template$23.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$24( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( DropdownItem.prototype, proto );

DropdownItem.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

DropdownItem.prototype.teardown = DropdownItem.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$24 = (function () {
  return {
    data() {
      return {
        class: '',
        right: false
      }
    }
  }
}());

function create_main_fragment$25 ( state, component ) {
	var div, div_class_value;

	return {
		create: function () {
			div = createElement( 'div' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			div.className = div_class_value = "dropdown-menu" + ( state.right ? ' dropdown-menu-right' : '' ) + " " + ( state.class );
			setAttribute( div, 'tabIndex', "-1" );
			setAttribute( div, 'role', "menu" );
		},

		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			if ( component._yield ) component._yield.mount( div, null );
		},

		update: function ( changed, state ) {
			if ( div_class_value !== ( div_class_value = "dropdown-menu" + ( state.right ? ' dropdown-menu-right' : '' ) + " " + ( state.class ) ) ) {
				div.className = div_class_value;
			}
		},

		unmount: function () {
			detachNode( div );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function DropdownMenu ( options ) {
	options = options || {};
	this._state = assign( template$24.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$25( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( DropdownMenu.prototype, proto );

DropdownMenu.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

DropdownMenu.prototype.teardown = DropdownMenu.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$25 = (function () {
  return {
    data() {
      return {
        class: '',
        inline: false
      }
    }
  }
}());

function create_main_fragment$26 ( state, component ) {
	var form, form_class_value;

	return {
		create: function () {
			form = createElement( 'form' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			form.className = form_class_value = "" + ( state.inline ? 'form-inline' : '' ) + " " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( form, target, anchor );
			if ( component._yield ) component._yield.mount( form, null );
		},

		update: function ( changed, state ) {
			if ( form_class_value !== ( form_class_value = "" + ( state.inline ? 'form-inline' : '' ) + " " + ( state.class ) ) ) {
				form.className = form_class_value;
			}
		},

		unmount: function () {
			detachNode( form );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function Form ( options ) {
	options = options || {};
	this._state = assign( template$25.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$26( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( Form.prototype, proto );

Form.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

Form.prototype.teardown = Form.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$26 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function create_main_fragment$27 ( state, component ) {
	var div, div_class_value;

	return {
		create: function () {
			div = createElement( 'div' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			div.className = div_class_value = "form-control-feedback " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			if ( component._yield ) component._yield.mount( div, null );
		},

		update: function ( changed, state ) {
			if ( div_class_value !== ( div_class_value = "form-control-feedback " + ( state.class ) ) ) {
				div.className = div_class_value;
			}
		},

		unmount: function () {
			detachNode( div );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function FormFeedback ( options ) {
	options = options || {};
	this._state = assign( template$26.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$27( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( FormFeedback.prototype, proto );

FormFeedback.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

FormFeedback.prototype.teardown = FormFeedback.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$27 = (function () {
  return {
    data() {
      return {
        check: false,
        class: '',
        color: null,
        disabled: false,
        row: false
      }
    }
  }
}());

function create_main_fragment$28 ( state, component ) {
	var div, div_class_value;

	return {
		create: function () {
			div = createElement( 'div' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			div.className = div_class_value = "" + ( state.color ? `has-${state.color}` : '' ) + ( state.row ? ' row' : '' ) + ( state.check ? ' form-check' : ' form-group' ) + ( state.check && state.disabled ? ' disabled' : '' ) + " " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			if ( component._yield ) component._yield.mount( div, null );
		},

		update: function ( changed, state ) {
			if ( div_class_value !== ( div_class_value = "" + ( state.color ? `has-${state.color}` : '' ) + ( state.row ? ' row' : '' ) + ( state.check ? ' form-check' : ' form-group' ) + ( state.check && state.disabled ? ' disabled' : '' ) + " " + ( state.class ) ) ) {
				div.className = div_class_value;
			}
		},

		unmount: function () {
			detachNode( div );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function FormGroup ( options ) {
	options = options || {};
	this._state = assign( template$27.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$28( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( FormGroup.prototype, proto );

FormGroup.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

FormGroup.prototype.teardown = FormGroup.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$28 = (function () {
  return {
    data() {
      return {
        class: '',
        color: null,
        inline: false
      }
    }
  }
}());

function create_main_fragment$29 ( state, component ) {
	var small, small_class_value;

	return {
		create: function () {
			small = createElement( 'small' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			small.className = small_class_value = "" + ( !state.inline ? 'form-text' : '' ) + ( state.color ? ` text-${state.color}` : '' ) + " " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( small, target, anchor );
			if ( component._yield ) component._yield.mount( small, null );
		},

		update: function ( changed, state ) {
			if ( small_class_value !== ( small_class_value = "" + ( !state.inline ? 'form-text' : '' ) + ( state.color ? ` text-${state.color}` : '' ) + " " + ( state.class ) ) ) {
				small.className = small_class_value;
			}
		},

		unmount: function () {
			detachNode( small );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function FormText ( options ) {
	options = options || {};
	this._state = assign( template$28.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$29( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( FormText.prototype, proto );

FormText.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

FormText.prototype.teardown = FormText.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$29 = (function () {
  return {
    data() {
      return {
        border: false,
        class: '',
        fixedWidth: false,
        flip: false,
        inverse: false,
        pulse: false,
        rotate: false,
        size: false,
        spin: false,
        stack: false
      }
    }
  }
}());

function create_main_fragment$30 ( state, component ) {
	var i, i_class_value;

	return {
		create: function () {
			i = createElement( 'i' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			i.className = i_class_value = "fa fa-" + ( state.name ) + ( state.size ? ' fa-' + state.size : '' ) + ( state.spin ? ' fa-spin' : '' ) + ( state.pulse ? ' fa-pulse' : '' ) + ( state.border ? ' fa-border' : '' ) + ( state.fixedWidth ? ' fa-fw' : '' ) + ( state.inverse ? ' fa-inverse' : '' ) + ( state.flip ? ' fa-flip-' + state.flip : '' ) + ( state.rotate ? ' fa-rotate-' + state.rotate : '' ) + ( state.stack ? ' fa-stack-' + state.stack : '' ) + " " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( i, target, anchor );
		},

		update: function ( changed, state ) {
			if ( i_class_value !== ( i_class_value = "fa fa-" + ( state.name ) + ( state.size ? ' fa-' + state.size : '' ) + ( state.spin ? ' fa-spin' : '' ) + ( state.pulse ? ' fa-pulse' : '' ) + ( state.border ? ' fa-border' : '' ) + ( state.fixedWidth ? ' fa-fw' : '' ) + ( state.inverse ? ' fa-inverse' : '' ) + ( state.flip ? ' fa-flip-' + state.flip : '' ) + ( state.rotate ? ' fa-rotate-' + state.rotate : '' ) + ( state.stack ? ' fa-stack-' + state.stack : '' ) + " " + ( state.class ) ) ) {
				i.className = i_class_value;
			}
		},

		unmount: function () {
			detachNode( i );
		},

		destroy: noop
	};
}

function Icon ( options ) {
	options = options || {};
	this._state = assign( template$29.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$30( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( Icon.prototype, proto );

Icon.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

Icon.prototype.teardown = Icon.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$30 = (function () {
  return {
    data() {
      return {
        class: '',
        size: null
      }
    }
  }
}());

function create_main_fragment$31 ( state, component ) {
	var div, div_class_value;

	return {
		create: function () {
			div = createElement( 'div' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			div.className = div_class_value = "input-group" + ( state.size ? ` input-group-${state.size}` : '' ) + " " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			if ( component._yield ) component._yield.mount( div, null );
		},

		update: function ( changed, state ) {
			if ( div_class_value !== ( div_class_value = "input-group" + ( state.size ? ` input-group-${state.size}` : '' ) + " " + ( state.class ) ) ) {
				div.className = div_class_value;
			}
		},

		unmount: function () {
			detachNode( div );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function InputGroup ( options ) {
	options = options || {};
	this._state = assign( template$30.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$31( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( InputGroup.prototype, proto );

InputGroup.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

InputGroup.prototype.teardown = InputGroup.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$31 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function create_main_fragment$32 ( state, component ) {
	var div, div_class_value;

	return {
		create: function () {
			div = createElement( 'div' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			div.className = div_class_value = "input-group-addon " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			if ( component._yield ) component._yield.mount( div, null );
		},

		update: function ( changed, state ) {
			if ( div_class_value !== ( div_class_value = "input-group-addon " + ( state.class ) ) ) {
				div.className = div_class_value;
			}
		},

		unmount: function () {
			detachNode( div );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function InputGroupAddon ( options ) {
	options = options || {};
	this._state = assign( template$31.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$32( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( InputGroupAddon.prototype, proto );

InputGroupAddon.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

InputGroupAddon.prototype.teardown = InputGroupAddon.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$32 = (function () {
  return {
    data() {
      return {
        class: '',
        fluid: false
      }
    }
  }
}());

function create_main_fragment$33 ( state, component ) {
	var div, div_class_value;

	return {
		create: function () {
			div = createElement( 'div' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			div.className = div_class_value = "jumbotron" + ( state.fluid ? ' jumbotron-fluid' : '' ) + " " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			if ( component._yield ) component._yield.mount( div, null );
		},

		update: function ( changed, state ) {
			if ( div_class_value !== ( div_class_value = "jumbotron" + ( state.fluid ? ' jumbotron-fluid' : '' ) + " " + ( state.class ) ) ) {
				div.className = div_class_value;
			}
		},

		unmount: function () {
			detachNode( div );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function Jumbotron ( options ) {
	options = options || {};
	this._state = assign( template$32.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$33( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( Jumbotron.prototype, proto );

Jumbotron.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

Jumbotron.prototype.teardown = Jumbotron.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$33 = (function () {
  return {
    data() {
      return {
        class: '',
        flush: false
      }
    }
  }
}());

function create_main_fragment$34 ( state, component ) {
	var ul, ul_class_value;

	return {
		create: function () {
			ul = createElement( 'ul' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			ul.className = ul_class_value = "list-group" + ( state.flush ? ' list-group-flush' : '' ) + " " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( ul, target, anchor );
			if ( component._yield ) component._yield.mount( ul, null );
		},

		update: function ( changed, state ) {
			if ( ul_class_value !== ( ul_class_value = "list-group" + ( state.flush ? ' list-group-flush' : '' ) + " " + ( state.class ) ) ) {
				ul.className = ul_class_value;
			}
		},

		unmount: function () {
			detachNode( ul );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function ListGroup ( options ) {
	options = options || {};
	this._state = assign( template$33.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$34( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( ListGroup.prototype, proto );

ListGroup.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

ListGroup.prototype.teardown = ListGroup.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$34 = (function () {
  return {
    data() {
      return {
        active: false,
        class: '',
        disabled: false,
        action: false,
        color: false
      }
    }
  }
}());

function create_main_fragment$35 ( state, component ) {
	var li, li_class_value;

	return {
		create: function () {
			li = createElement( 'li' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			li.className = li_class_value = "list-group-item" + ( state.active ? ' active' : '' ) + ( state.disabled ? ' disabled' : '' ) + ( state.action ? ' list-group-item-action' : '' ) + ( state.color ? ` list-group-item-${state.color}` : '' ) + " " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( li, target, anchor );
			if ( component._yield ) component._yield.mount( li, null );
		},

		update: function ( changed, state ) {
			if ( li_class_value !== ( li_class_value = "list-group-item" + ( state.active ? ' active' : '' ) + ( state.disabled ? ' disabled' : '' ) + ( state.action ? ' list-group-item-action' : '' ) + ( state.color ? ` list-group-item-${state.color}` : '' ) + " " + ( state.class ) ) ) {
				li.className = li_class_value;
			}
		},

		unmount: function () {
			detachNode( li );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function ListGroupItem ( options ) {
	options = options || {};
	this._state = assign( template$34.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$35( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( ListGroupItem.prototype, proto );

ListGroupItem.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

ListGroupItem.prototype.teardown = ListGroupItem.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$35 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function create_main_fragment$36 ( state, component ) {
	var h5, h5_class_value;

	return {
		create: function () {
			h5 = createElement( 'h5' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			h5.className = h5_class_value = "list-group-item-heading " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( h5, target, anchor );
			if ( component._yield ) component._yield.mount( h5, null );
		},

		update: function ( changed, state ) {
			if ( h5_class_value !== ( h5_class_value = "list-group-item-heading " + ( state.class ) ) ) {
				h5.className = h5_class_value;
			}
		},

		unmount: function () {
			detachNode( h5 );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function ListGroupItemHeading ( options ) {
	options = options || {};
	this._state = assign( template$35.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$36( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( ListGroupItemHeading.prototype, proto );

ListGroupItemHeading.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

ListGroupItemHeading.prototype.teardown = ListGroupItemHeading.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$36 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function create_main_fragment$37 ( state, component ) {
	var p, p_class_value;

	return {
		create: function () {
			p = createElement( 'p' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			p.className = p_class_value = "list-group-item-text " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( p, target, anchor );
			if ( component._yield ) component._yield.mount( p, null );
		},

		update: function ( changed, state ) {
			if ( p_class_value !== ( p_class_value = "list-group-item-text " + ( state.class ) ) ) {
				p.className = p_class_value;
			}
		},

		unmount: function () {
			detachNode( p );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function ListGroupItemText ( options ) {
	options = options || {};
	this._state = assign( template$36.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$37( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( ListGroupItemText.prototype, proto );

ListGroupItemText.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

ListGroupItemText.prototype.teardown = ListGroupItemText.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$37 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  };
}());

function create_main_fragment$38 ( state, component ) {
	var div, div_class_value;

	return {
		create: function () {
			div = createElement( 'div' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			div.className = div_class_value = "media " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			if ( component._yield ) component._yield.mount( div, null );
		},

		update: function ( changed, state ) {
			if ( div_class_value !== ( div_class_value = "media " + ( state.class ) ) ) {
				div.className = div_class_value;
			}
		},

		unmount: function () {
			detachNode( div );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function Media ( options ) {
	options = options || {};
	this._state = assign( template$37.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$38( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( Media.prototype, proto );

Media.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

Media.prototype.teardown = Media.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$38 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  };
}());

function create_main_fragment$39 ( state, component ) {
	var div, div_class_value;

	return {
		create: function () {
			div = createElement( 'div' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			div.className = div_class_value = "media-body " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			if ( component._yield ) component._yield.mount( div, null );
		},

		update: function ( changed, state ) {
			if ( div_class_value !== ( div_class_value = "media-body " + ( state.class ) ) ) {
				div.className = div_class_value;
			}
		},

		unmount: function () {
			detachNode( div );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function MediaBody ( options ) {
	options = options || {};
	this._state = assign( template$38.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$39( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( MediaBody.prototype, proto );

MediaBody.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

MediaBody.prototype.teardown = MediaBody.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$39 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function create_main_fragment$40 ( state, component ) {
	var div, div_class_value;

	return {
		create: function () {
			div = createElement( 'div' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			div.className = div_class_value = "modal-footer " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			if ( component._yield ) component._yield.mount( div, null );
		},

		update: function ( changed, state ) {
			if ( div_class_value !== ( div_class_value = "modal-footer " + ( state.class ) ) ) {
				div.className = div_class_value;
			}
		},

		unmount: function () {
			detachNode( div );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function ModalFooter ( options ) {
	options = options || {};
	this._state = assign( template$39.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$40( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( ModalFooter.prototype, proto );

ModalFooter.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

ModalFooter.prototype.teardown = ModalFooter.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$40 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function create_main_fragment$41 ( state, component ) {
	var li, li_class_value;

	return {
		create: function () {
			li = createElement( 'li' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			li.className = li_class_value = "nav-item " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( li, target, anchor );
			if ( component._yield ) component._yield.mount( li, null );
		},

		update: function ( changed, state ) {
			if ( li_class_value !== ( li_class_value = "nav-item " + ( state.class ) ) ) {
				li.className = li_class_value;
			}
		},

		unmount: function () {
			detachNode( li );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function NavDropdown ( options ) {
	options = options || {};
	this._state = assign( template$40.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$41( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( NavDropdown.prototype, proto );

NavDropdown.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

NavDropdown.prototype.teardown = NavDropdown.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$41 = (function () {
  return {
    data() {
      return {
        class: '',
        fill: false,
        justified: false,
        navbar: false,
        pills: false,
        tabs: false,
        vertical: false
      }
    }
  }
}());

function create_main_fragment$42 ( state, component ) {
	var ul, ul_class_value;

	return {
		create: function () {
			ul = createElement( 'ul' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			ul.className = ul_class_value = "" + ( state.navbar ? 'navbar-nav' : 'nav' ) + ( state.tabs ? ' nav-tabs' : '' ) + ( state.pills ? ' nav-pills' : '' ) + ( state.fill ? ' nav-fill' : state.justified ? ' nav-justified' : '' ) + ( state.vertical ? ' flex-column' : '' ) + " " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( ul, target, anchor );
			if ( component._yield ) component._yield.mount( ul, null );
		},

		update: function ( changed, state ) {
			if ( ul_class_value !== ( ul_class_value = "" + ( state.navbar ? 'navbar-nav' : 'nav' ) + ( state.tabs ? ' nav-tabs' : '' ) + ( state.pills ? ' nav-pills' : '' ) + ( state.fill ? ' nav-fill' : state.justified ? ' nav-justified' : '' ) + ( state.vertical ? ' flex-column' : '' ) + " " + ( state.class ) ) ) {
				ul.className = ul_class_value;
			}
		},

		unmount: function () {
			detachNode( ul );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function Nav ( options ) {
	options = options || {};
	this._state = assign( template$41.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$42( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( Nav.prototype, proto );

Nav.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

Nav.prototype.teardown = Nav.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$42 = (function () {
  return {
    data() {
      return {
        active: false,
        class: ''
      }
    }
  }
}());

function create_main_fragment$43 ( state, component ) {
	var li, li_class_value;

	return {
		create: function () {
			li = createElement( 'li' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			li.className = li_class_value = "nav-item" + ( state.active ? ' active' : '' ) + " " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( li, target, anchor );
			if ( component._yield ) component._yield.mount( li, null );
		},

		update: function ( changed, state ) {
			if ( li_class_value !== ( li_class_value = "nav-item" + ( state.active ? ' active' : '' ) + " " + ( state.class ) ) ) {
				li.className = li_class_value;
			}
		},

		unmount: function () {
			detachNode( li );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function NavItem ( options ) {
	options = options || {};
	this._state = assign( template$42.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$43( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( NavItem.prototype, proto );

NavItem.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

NavItem.prototype.teardown = NavItem.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$43 = (function () {
  return {
    data() {
      return {
        active: false,
        disabled: false,
        href: '#',
        class: ''
      }
    },
    methods: {
      onClick(e) {
        const { disabled, href } = this.get();
        if (disabled) {
          e.preventDefault();
          return;
        }

        if (href === '#') {
          e.preventDefault();
        }

        this.fire('click', e);
      }
    }
  }
}());

function create_main_fragment$44 ( state, component ) {
	var a, a_href_value, a_class_value;

	function click_handler ( event ) {
		component.onClick(event);
	}

	return {
		create: function () {
			a = createElement( 'a' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			a.href = a_href_value = state.href;
			a.className = a_class_value = "nav-link" + ( state.disabled ? ' disabled' : '' ) + ( state.active ? ' active' : '' ) + " " + ( state.class );
			addListener( a, 'click', click_handler );
		},

		mount: function ( target, anchor ) {
			insertNode( a, target, anchor );
			if ( component._yield ) component._yield.mount( a, null );
		},

		update: function ( changed, state ) {
			if ( a_href_value !== ( a_href_value = state.href ) ) {
				a.href = a_href_value;
			}

			if ( a_class_value !== ( a_class_value = "nav-link" + ( state.disabled ? ' disabled' : '' ) + ( state.active ? ' active' : '' ) + " " + ( state.class ) ) ) {
				a.className = a_class_value;
			}
		},

		unmount: function () {
			detachNode( a );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: function () {
			removeListener( a, 'click', click_handler );
		}
	};
}

function NavLink ( options ) {
	options = options || {};
	this._state = assign( template$43.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$44( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( NavLink.prototype, template$43.methods, proto );

NavLink.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

NavLink.prototype.teardown = NavLink.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$44 = (function () {
  return {
    data() {
      return {
        class: ''
      }
    }
  }
}());

function create_main_fragment$45 ( state, component ) {
	var a, a_class_value;

	return {
		create: function () {
			a = createElement( 'a' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			a.className = a_class_value = "navbar-brand " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( a, target, anchor );
			if ( component._yield ) component._yield.mount( a, null );
		},

		update: function ( changed, state ) {
			if ( a_class_value !== ( a_class_value = "navbar-brand " + ( state.class ) ) ) {
				a.className = a_class_value;
			}
		},

		unmount: function () {
			detachNode( a );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function NavbarBrand ( options ) {
	options = options || {};
	this._state = assign( template$44.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$45( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( NavbarBrand.prototype, proto );

NavbarBrand.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

NavbarBrand.prototype.teardown = NavbarBrand.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$45 = (function () {
  return {
    data() {
      return {
        class: '',
        size: null
      }
    }
  }
}());

function create_main_fragment$46 ( state, component ) {
	var ul, ul_class_value;

	return {
		create: function () {
			ul = createElement( 'ul' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			ul.className = ul_class_value = "pagination" + ( state.size ? ` pagination-${state.size}` : '' ) + " " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( ul, target, anchor );
			if ( component._yield ) component._yield.mount( ul, null );
		},

		update: function ( changed, state ) {
			if ( ul_class_value !== ( ul_class_value = "pagination" + ( state.size ? ` pagination-${state.size}` : '' ) + " " + ( state.class ) ) ) {
				ul.className = ul_class_value;
			}
		},

		unmount: function () {
			detachNode( ul );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function Pagination ( options ) {
	options = options || {};
	this._state = assign( template$45.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$46( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( Pagination.prototype, proto );

Pagination.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

Pagination.prototype.teardown = Pagination.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$46 = (function () {
  return {
    data() {
      return {
        active: false,
        class: '',
        disabled: false
      }
    }
  }
}());

function create_main_fragment$47 ( state, component ) {
	var li, li_class_value;

	return {
		create: function () {
			li = createElement( 'li' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			li.className = li_class_value = "page-item" + ( state.active ? ' active' : '' ) + ( state.disabled ? ' disabled' : '' ) + " " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( li, target, anchor );
			if ( component._yield ) component._yield.mount( li, null );
		},

		update: function ( changed, state ) {
			if ( li_class_value !== ( li_class_value = "page-item" + ( state.active ? ' active' : '' ) + ( state.disabled ? ' disabled' : '' ) + " " + ( state.class ) ) ) {
				li.className = li_class_value;
			}
		},

		unmount: function () {
			detachNode( li );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function PaginationItem ( options ) {
	options = options || {};
	this._state = assign( template$46.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$47( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( PaginationItem.prototype, proto );

PaginationItem.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

PaginationItem.prototype.teardown = PaginationItem.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$47 = (function () {
  // TODO add state to this component, generate PaginationItems, Links, on:click, etc
  return {
    data() {
      return {
        class: '',
        next: false,
        previous: false
      }
    }
  }
}());

function create_main_fragment$48 ( state, component ) {
	var a, a_class_value;

	function get_block ( state ) {
		if ( state.previous ) return create_if_block$1;
		if ( state.next ) return create_if_block_1$1;
		return create_if_block_2;
	}

	var current_block = get_block( state );
	var if_block = current_block( state, component );

	return {
		create: function () {
			a = createElement( 'a' );
			if_block.create();
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			a.className = a_class_value = "page-link" + ( state.size ? ` pagination-${state.size}` : '' ) + " " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( a, target, anchor );
			if_block.mount( a, null );
		},

		update: function ( changed, state ) {
			if ( a_class_value !== ( a_class_value = "page-link" + ( state.size ? ` pagination-${state.size}` : '' ) + " " + ( state.class ) ) ) {
				a.className = a_class_value;
			}

			if ( current_block !== ( current_block = get_block( state ) ) ) {
				if_block.unmount();
				if_block.destroy();
				if_block = current_block( state, component );
				if_block.create();
				if_block.mount( a, null );
			}
		},

		unmount: function () {
			detachNode( a );
			if_block.unmount();
		},

		destroy: function () {
			if_block.destroy();
		}
	};
}

function create_if_block$1 ( state, component ) {
	var text;

	return {
		create: function () {
			text = createText( "«" );
		},

		mount: function ( target, anchor ) {
			insertNode( text, target, anchor );
		},

		unmount: function () {
			detachNode( text );
		},

		destroy: noop
	};
}

function create_if_block_1$1 ( state, component ) {
	var text;

	return {
		create: function () {
			text = createText( "»" );
		},

		mount: function ( target, anchor ) {
			insertNode( text, target, anchor );
		},

		unmount: function () {
			detachNode( text );
		},

		destroy: noop
	};
}

function create_if_block_2 ( state, component ) {

	return {
		create: noop,

		mount: function ( target, anchor ) {
			if ( component._yield ) component._yield.mount( target, null );
		},

		unmount: function () {
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function PaginationLink ( options ) {
	options = options || {};
	this._state = assign( template$47.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$48( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( PaginationLink.prototype, proto );

PaginationLink.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

PaginationLink.prototype.teardown = PaginationLink.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

/**
 * lodash (Custom Build) <https://lodash.com/>
 * Build: `lodash modularize exports="npm" -o ./`
 * Copyright jQuery Foundation and other contributors <https://jquery.org/>
 * Released under MIT license <https://lodash.com/license>
 * Based on Underscore.js 1.8.3 <http://underscorejs.org/LICENSE>
 * Copyright Jeremy Ashkenas, DocumentCloud and Investigative Reporters & Editors
 */

/** Used as references for various `Number` constants. */
var NAN = 0 / 0;

/** `Object#toString` result references. */
var symbolTag = '[object Symbol]';

/** Used to match leading and trailing whitespace. */
var reTrim = /^\s+|\s+$/g;

/** Used to detect bad signed hexadecimal string values. */
var reIsBadHex = /^[-+]0x[0-9a-f]+$/i;

/** Used to detect binary string values. */
var reIsBinary = /^0b[01]+$/i;

/** Used to detect octal string values. */
var reIsOctal = /^0o[0-7]+$/i;

/** Built-in method references without a dependency on `root`. */
var freeParseInt = parseInt;

/** Used for built-in method references. */
var objectProto = Object.prototype;

/**
 * Used to resolve the
 * [`toStringTag`](http://ecma-international.org/ecma-262/7.0/#sec-object.prototype.tostring)
 * of values.
 */
var objectToString = objectProto.toString;

/**
 * Checks if `value` is the
 * [language type](http://www.ecma-international.org/ecma-262/7.0/#sec-ecmascript-language-types)
 * of `Object`. (e.g. arrays, functions, objects, regexes, `new Number(0)`, and `new String('')`)
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is an object, else `false`.
 * @example
 *
 * _.isObject({});
 * // => true
 *
 * _.isObject([1, 2, 3]);
 * // => true
 *
 * _.isObject(_.noop);
 * // => true
 *
 * _.isObject(null);
 * // => false
 */
function isObject(value) {
  var type = typeof value;
  return !!value && (type == 'object' || type == 'function');
}

/**
 * Checks if `value` is object-like. A value is object-like if it's not `null`
 * and has a `typeof` result of "object".
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is object-like, else `false`.
 * @example
 *
 * _.isObjectLike({});
 * // => true
 *
 * _.isObjectLike([1, 2, 3]);
 * // => true
 *
 * _.isObjectLike(_.noop);
 * // => false
 *
 * _.isObjectLike(null);
 * // => false
 */
function isObjectLike(value) {
  return !!value && typeof value == 'object';
}

/**
 * Checks if `value` is classified as a `Symbol` primitive or object.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a symbol, else `false`.
 * @example
 *
 * _.isSymbol(Symbol.iterator);
 * // => true
 *
 * _.isSymbol('abc');
 * // => false
 */
function isSymbol(value) {
  return typeof value == 'symbol' ||
    (isObjectLike(value) && objectToString.call(value) == symbolTag);
}

/**
 * Converts `value` to a number.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to process.
 * @returns {number} Returns the number.
 * @example
 *
 * _.toNumber(3.2);
 * // => 3.2
 *
 * _.toNumber(Number.MIN_VALUE);
 * // => 5e-324
 *
 * _.toNumber(Infinity);
 * // => Infinity
 *
 * _.toNumber('3.2');
 * // => 3.2
 */
function toNumber$1(value) {
  if (typeof value == 'number') {
    return value;
  }
  if (isSymbol(value)) {
    return NAN;
  }
  if (isObject(value)) {
    var other = typeof value.valueOf == 'function' ? value.valueOf() : value;
    value = isObject(other) ? (other + '') : other;
  }
  if (typeof value != 'string') {
    return value === 0 ? value : +value;
  }
  value = value.replace(reTrim, '');
  var isBinary = reIsBinary.test(value);
  return (isBinary || reIsOctal.test(value))
    ? freeParseInt(value.slice(2), isBinary ? 2 : 8)
    : (reIsBadHex.test(value) ? NAN : +value);
}

var index = toNumber$1;

function recompute$1 ( state, newState, oldState, isInitial ) {
	if ( isInitial || ( 'value' in newState && differs( state.value, oldState.value ) ) || ( 'max' in newState && differs( state.max, oldState.max ) ) ) {
		state.percent = newState.percent = template$48.computed.percent( state.value, state.max );
	}
}

var template$48 = (function () {
return {
  data() {
    return {
      bar: false,
      class: '',
      value: 0,
      max: 100,
      multi: false
    }
  },
  computed: {
    percent(value, max) {
      return (index(value) / index(max)) * 100;
    }
  }
}
}());

function create_main_fragment$49 ( state, component ) {
	var if_block_anchor;

	function get_block ( state ) {
		if ( !state.bar ) return create_if_block$2;
		return create_if_block_3;
	}

	var current_block = get_block( state );
	var if_block = current_block( state, component );

	return {
		create: function () {
			if_block.create();
			if_block_anchor = createComment();
		},

		mount: function ( target, anchor ) {
			if_block.mount( target, anchor );
			insertNode( if_block_anchor, target, anchor );
		},

		update: function ( changed, state ) {
			if ( current_block === ( current_block = get_block( state ) ) && if_block ) {
				if_block.update( changed, state );
			} else {
				if_block.unmount();
				if_block.destroy();
				if_block = current_block( state, component );
				if_block.create();
				if_block.mount( if_block_anchor.parentNode, if_block_anchor );
			}
		},

		unmount: function () {
			if_block.unmount();
			detachNode( if_block_anchor );
		},

		destroy: function () {
			if_block.destroy();
		}
	};
}

function create_if_block_1$2 ( state, component ) {

	return {
		create: noop,

		mount: function ( target, anchor ) {
			if ( component._yield ) component._yield.mount( target, null );
		},

		update: noop,

		unmount: function () {
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function create_if_block_2$1 ( state, component ) {
	var div, div_class_value, div_style_value;

	return {
		create: function () {
			div = createElement( 'div' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			div.className = div_class_value = "progress-bar" + ( state.animated ? ' progress-bar-animated' : '' ) + ( state.color ? ` bg-${state.color}` : '' ) + ( state.striped || state.animated ? ' progress-bar-striped' : '' );
			div.style.cssText = div_style_value = "width:" + ( state.percent ) + "%";
		},

		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			if ( component._yield ) component._yield.mount( div, null );
		},

		update: function ( changed, state ) {
			if ( div_class_value !== ( div_class_value = "progress-bar" + ( state.animated ? ' progress-bar-animated' : '' ) + ( state.color ? ` bg-${state.color}` : '' ) + ( state.striped || state.animated ? ' progress-bar-striped' : '' ) ) ) {
				div.className = div_class_value;
			}

			if ( div_style_value !== ( div_style_value = "width:" + ( state.percent ) + "%" ) ) {
				div.style.cssText = div_style_value;
			}
		},

		unmount: function () {
			detachNode( div );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function create_if_block$2 ( state, component ) {
	var div, div_class_value;

	function get_block ( state ) {
		if ( state.multi ) return create_if_block_1$2;
		return create_if_block_2$1;
	}

	var current_block = get_block( state );
	var if_block_1 = current_block( state, component );

	return {
		create: function () {
			div = createElement( 'div' );
			if_block_1.create();
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			div.className = div_class_value = "progress " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			if_block_1.mount( div, null );
		},

		update: function ( changed, state ) {
			if ( div_class_value !== ( div_class_value = "progress " + ( state.class ) ) ) {
				div.className = div_class_value;
			}

			if ( current_block === ( current_block = get_block( state ) ) && if_block_1 ) {
				if_block_1.update( changed, state );
			} else {
				if_block_1.unmount();
				if_block_1.destroy();
				if_block_1 = current_block( state, component );
				if_block_1.create();
				if_block_1.mount( div, null );
			}
		},

		unmount: function () {
			detachNode( div );
			if_block_1.unmount();
		},

		destroy: function () {
			if_block_1.destroy();
		}
	};
}

function create_if_block_3 ( state, component ) {
	var div, div_class_value, div_style_value;

	return {
		create: function () {
			div = createElement( 'div' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			div.className = div_class_value = "progress-bar" + ( state.animated ? ' progress-bar-animated' : '' ) + ( state.color ? ` bg-${state.color}` : '' ) + ( state.striped || state.animated ? ' progress-bar-striped' : '' );
			div.style.cssText = div_style_value = "width:" + ( state.percent ) + "%";
		},

		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			if ( component._yield ) component._yield.mount( div, null );
		},

		update: function ( changed, state ) {
			if ( div_class_value !== ( div_class_value = "progress-bar" + ( state.animated ? ' progress-bar-animated' : '' ) + ( state.color ? ` bg-${state.color}` : '' ) + ( state.striped || state.animated ? ' progress-bar-striped' : '' ) ) ) {
				div.className = div_class_value;
			}

			if ( div_style_value !== ( div_style_value = "width:" + ( state.percent ) + "%" ) ) {
				div.style.cssText = div_style_value;
			}
		},

		unmount: function () {
			detachNode( div );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function Progress ( options ) {
	options = options || {};
	this._state = assign( template$48.data(), options.data );
	recompute$1( this._state, this._state, {}, true );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$49( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( Progress.prototype, proto );

Progress.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	recompute$1( this._state, newState, oldState, false );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

Progress.prototype.teardown = Progress.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$49 = (function () {
  return {
    data() {
      return {
        class: '',
        noGutters: false
      }
    }
  };
}());

function create_main_fragment$50 ( state, component ) {
	var div, div_class_value;

	return {
		create: function () {
			div = createElement( 'div' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			div.className = div_class_value = "row" + ( state.noGutters ? ' no-gutters' : '' ) + " " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			if ( component._yield ) component._yield.mount( div, null );
		},

		update: function ( changed, state ) {
			if ( div_class_value !== ( div_class_value = "row" + ( state.noGutters ? ' no-gutters' : '' ) + " " + ( state.class ) ) ) {
				div.className = div_class_value;
			}
		},

		unmount: function () {
			detachNode( div );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function Row ( options ) {
	options = options || {};
	this._state = assign( template$49.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$50( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( Row.prototype, proto );

Row.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

Row.prototype.teardown = Row.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

var template$50 = (function () {
  // TODO remove duplication of table above
  return {
    data() {
      return {
        class: '',
        size: null,
        bordered: false,
        striped: false,
        inverse: false,
        hover: false,
        reflow: false
      }
    }
  }
}());

function create_main_fragment$51 ( state, component ) {
	var if_block_anchor;

	function get_block ( state ) {
		if ( state.responsive ) return create_if_block$3;
		return create_if_block_1$3;
	}

	var current_block = get_block( state );
	var if_block = current_block( state, component );

	return {
		create: function () {
			if_block.create();
			if_block_anchor = createComment();
		},

		mount: function ( target, anchor ) {
			if_block.mount( target, anchor );
			insertNode( if_block_anchor, target, anchor );
		},

		update: function ( changed, state ) {
			if ( current_block === ( current_block = get_block( state ) ) && if_block ) {
				if_block.update( changed, state );
			} else {
				if_block.unmount();
				if_block.destroy();
				if_block = current_block( state, component );
				if_block.create();
				if_block.mount( if_block_anchor.parentNode, if_block_anchor );
			}
		},

		unmount: function () {
			if_block.unmount();
			detachNode( if_block_anchor );
		},

		destroy: function () {
			if_block.destroy();
		}
	};
}

function create_if_block$3 ( state, component ) {
	var div, table, table_class_value;

	return {
		create: function () {
			div = createElement( 'div' );
			table = createElement( 'table' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			div.className = "table-responsive";
			table.className = table_class_value = "table" + ( state.size ? ` table-${state.size}` : '' ) + ( state.bordered ? ' table-bordered' : '' ) + ( state.striped ? ' table-striped' : '' ) + ( state.inverse ? ' table-inverse' : '' ) + ( state.hover ? ' table-hover' : '' ) + ( state.reflow ? ' table-reflow' :'' ) + "\n   " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( div, target, anchor );
			appendNode( table, div );
			if ( component._yield ) component._yield.mount( table, null );
		},

		update: function ( changed, state ) {
			if ( table_class_value !== ( table_class_value = "table" + ( state.size ? ` table-${state.size}` : '' ) + ( state.bordered ? ' table-bordered' : '' ) + ( state.striped ? ' table-striped' : '' ) + ( state.inverse ? ' table-inverse' : '' ) + ( state.hover ? ' table-hover' : '' ) + ( state.reflow ? ' table-reflow' :'' ) + "\n   " + ( state.class ) ) ) {
				table.className = table_class_value;
			}
		},

		unmount: function () {
			detachNode( div );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function create_if_block_1$3 ( state, component ) {
	var table, table_class_value;

	return {
		create: function () {
			table = createElement( 'table' );
			this.hydrate();
		},

		hydrate: function ( nodes ) {
			table.className = table_class_value = "table" + ( state.size ? ` table-${state.size}` : '' ) + ( state.bordered ? ' table-bordered' : '' ) + ( state.striped ? ' table-striped' : '' ) + ( state.inverse ? ' table-inverse' : '' ) + ( state.hover ? ' table-hover' : '' ) + ( state.reflow ? ' table-reflow' :'' ) + "\n   " + ( state.class );
		},

		mount: function ( target, anchor ) {
			insertNode( table, target, anchor );
			if ( component._yield ) component._yield.mount( table, null );
		},

		update: function ( changed, state ) {
			if ( table_class_value !== ( table_class_value = "table" + ( state.size ? ` table-${state.size}` : '' ) + ( state.bordered ? ' table-bordered' : '' ) + ( state.striped ? ' table-striped' : '' ) + ( state.inverse ? ' table-inverse' : '' ) + ( state.hover ? ' table-hover' : '' ) + ( state.reflow ? ' table-reflow' :'' ) + "\n   " + ( state.class ) ) ) {
				table.className = table_class_value;
			}
		},

		unmount: function () {
			detachNode( table );
			if ( component._yield ) component._yield.unmount();
		},

		destroy: noop
	};
}

function Table ( options ) {
	options = options || {};
	this._state = assign( template$50.data(), options.data );

	this._observers = {
		pre: Object.create( null ),
		post: Object.create( null )
	};

	this._handlers = Object.create( null );

	this._root = options._root || this;
	this._yield = options._yield;

	this._torndown = false;

	this._fragment = create_main_fragment$51( this._state, this );

	if ( options.target ) {
		this._fragment.create();
		this._fragment.mount( options.target, null );
	}
}

assign( Table.prototype, proto );

Table.prototype._set = function _set ( newState ) {
	var oldState = this._state;
	this._state = assign( {}, oldState, newState );
	dispatchObservers( this, this._observers.pre, newState, oldState );
	this._fragment.update( newState, this._state );
	dispatchObservers( this, this._observers.post, newState, oldState );
};

Table.prototype.teardown = Table.prototype.destroy = function destroy ( detach ) {
	this.fire( 'destroy' );

	if ( detach !== false ) this._fragment.unmount();
	this._fragment.destroy();
	this._fragment = null;

	this._state = {};
	this._torndown = true;
};

exports.Alert = Alert;
exports.Badge = Badge;
exports.Breadcrumb = Breadcrumb;
exports.BreadcrumbItem = BreadcrumbItem;
exports.Button = Button;
exports.ButtonGroup = ButtonGroup;
exports.ButtonToolbar = ButtonToolbar;
exports.Card = Card;
exports.CardBlock = CardBlock;
exports.CardColumns = CardColumns;
exports.CardDeck = CardDeck;
exports.CardFooter = CardFooter;
exports.CardGroup = CardGroup;
exports.CardHeader = CardHeader;
exports.CardImgOverlay = CardImgOverlay;
exports.CardSubtitle = CardSubtitle;
exports.CardText = CardText;
exports.CardTitle = CardTitle;
exports.Close = Close;
exports.Col = Col;
exports.Container = Container;
exports.Dropdown = Dropdown;
exports.DropdownDivider = DropdownDivider;
exports.DropdownHeader = DropdownHeader;
exports.DropdownItem = DropdownItem;
exports.DropdownMenu = DropdownMenu;
exports.Form = Form;
exports.FormFeedback = FormFeedback;
exports.FormGroup = FormGroup;
exports.FormText = FormText;
exports.Icon = Icon;
exports.InputGroup = InputGroup;
exports.InputGroupAddon = InputGroupAddon;
exports.Jumbotron = Jumbotron;
exports.ListGroup = ListGroup;
exports.ListGroupItem = ListGroupItem;
exports.ListGroupItemHeading = ListGroupItemHeading;
exports.ListGroupItemText = ListGroupItemText;
exports.Media = Media;
exports.MediaBody = MediaBody;
exports.ModalFooter = ModalFooter;
exports.NavDropdown = NavDropdown;
exports.Nav = Nav;
exports.NavItem = NavItem;
exports.NavLink = NavLink;
exports.NavbarBrand = NavbarBrand;
exports.Pagination = Pagination;
exports.PaginationItem = PaginationItem;
exports.PaginationLink = PaginationLink;
exports.Progress = Progress;
exports.Row = Row;
exports.Table = Table;
